@@ -20,6 +20,7 @@ use crate::{
     BitReader, Record,
 };
 
+#[allow(clippy::enum_variant_names)]
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub enum ReadRecordError {
     MissingDataSeriesEncoding(DataSeries),
@@ -886,7 +887,7 @@ where
             reader.read_u8()
         }
         Encoding::Huffman(alphabet, bit_lens) => {
-            let decoder = CanonicalHuffmanDecoder::new(&alphabet, &bit_lens);
+            let decoder = CanonicalHuffmanDecoder::new(alphabet, bit_lens);
             decoder.read(core_data_reader).map(|i| i as u8)
         }
         Encoding::Beta(offset, len) => core_data_reader
@@ -919,7 +920,7 @@ where
             read_itf8(reader)
         }
         Encoding::Huffman(alphabet, bit_lens) => {
-            let decoder = CanonicalHuffmanDecoder::new(&alphabet, &bit_lens);
+            let decoder = CanonicalHuffmanDecoder::new(alphabet, bit_lens);
             decoder.read(core_data_reader)
         }
         Encoding::Beta(offset, len) => core_data_reader
@@ -956,11 +957,11 @@ where
             Ok(buf)
         }
         Encoding::ByteArrayLen(len_encoding, value_encoding) => {
-            let len = decode_itf8(&len_encoding, core_data_reader, external_data_readers)?;
+            let len = decode_itf8(len_encoding, core_data_reader, external_data_readers)?;
 
             let buf = vec![0; len as usize];
             let value = decode_byte_array(
-                &value_encoding,
+                value_encoding,
                 core_data_reader,
                 external_data_readers,
                 Some(buf),
