@@ -21,6 +21,7 @@ use crate::{
     BitWriter, Record,
 };
 
+#[allow(clippy::enum_variant_names)]
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub enum WriteRecordError {
     MissingDataSeriesEncoding(DataSeries),
@@ -915,10 +916,10 @@ where
         }
         Encoding::ByteArrayLen(len_encoding, value_encoding) => {
             let len = data.len() as Itf8;
-            encode_itf8(&len_encoding, core_data_writer, external_data_writers, len)?;
+            encode_itf8(len_encoding, core_data_writer, external_data_writers, len)?;
 
             encode_byte_array(
-                &value_encoding,
+                value_encoding,
                 core_data_writer,
                 external_data_writers,
                 data,
